# spec file for PSPP 1.2.0

# Copyright (c) 2008 Matj Cepl <mcepl@redhat.com>
# Copyright (c) 2008 D. Steuer <steuer@hsuhh.de>
# Copyright (c) 2018 <astieger@suse.com>
# Copyright (c) 2010-2019 <opensuse.lietuviu.kalba@gmail.com>

# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Usable with currently supported openSUSE releases
# 42.3, 15.0, TW

%if 0%{?mandriva_version}
%define _disable_ld_no_undefined 1
#Next line is needed for Mandriva build
%define _disable_ld_as_needed 1
%endif

Name:           pspp
Version:        1.2.0
Release:        lp152.3.12
Summary:        A program for statistical analysis of sampled data

Group:          Productivity/Scientific/Math
License:        GPL-3.0+
URL:            http://www.gnu.org/software/pspp/
Source0:        ftp://ftp.gnu.org/pub/gnu/pspp/pspp-%{version}.tar.gz
Source1:        ftp://ftp.gnu.org/pub/gnu/pspp/pspp-%{version}.tar.gz.sig
Source2:        https://savannah.gnu.org/people/viewgpg.php?user_id=245#/%{name}.keyring
# PATCH-FIX-UPSTREAM CVE-2018-20230.patch bnc#1120061 CVE-2018-20230
Patch0:         CVE-2018-20230.patch
# PATCH-FIX-UPSTREAM CVE-2019-9211.patch boo#1127343 CVE-2019-9211
Patch1:         CVE-2019-9211.patch
# Fix build with Texinfo 4.13 for openSUSE Leap 42.*
Patch2:         avoid_old_Texinfo_4.13.patch

BuildRoot:      %{_tmppath}/pspp-root
%if 0%{?centos_version}
BuildRequires:  perl
BuildRequires:  perl-ExtUtils-MakeMaker
BuildRequires:  pkgconfig
BuildRequires:  gtksourceview3-devel
%endif
%if 0%{?fedora}
BuildRequires:  atlas
BuildRequires:  perl
BuildRequires:  perl-ExtUtils-MakeMaker
BuildRequires:  pkgconfig
BuildRequires:  gtksourceview3-devel
%endif
%if 0%{?mandriva_version}
BuildRequires:  perl
BuildRequires:  pkgconfig
BuildRequires:  gtksourceview-devel
%endif
%if 0%{?suse_version}
BuildRequires:  fdupes
BuildRequires:  perl-base
BuildRequires:  pkg-config
BuildRequires:  update-desktop-files
PreReq:         %install_info_prereq
%endif
%if  0%{?suse_version}
BuildRequires:  gtksourceview-devel >= 3.18.0
%endif
%if 0%{?suse_version}
#Next package only for "make check"
BuildRequires:  free-ttf-fonts
%endif
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cairo-devel
BuildRequires:  desktop-file-utils
BuildRequires:  gettext
BuildRequires:  gsl-devel >= 1.12
BuildRequires:  gtk3-devel >= 3.14.5
BuildRequires:  libglade2-devel
BuildRequires:  libxml2-devel
BuildRequires:  m4
BuildRequires:  pango-devel
BuildRequires:  postgresql-devel
%if  0%{?suse_version} <= 1310
BuildRequires:  postgresql-libs
%else
# BuildRequires:  postgresql93-libs
%endif
BuildRequires:  readline-devel
BuildRequires:  spread-sheet-widget-devel >= 0.3
BuildRequires:  texinfo
BuildRequires:  zlib-devel
%if 0%{?suse_version} <= 1320
BuildRequires:  libtool
%endif
Requires:       yelp

%description
PSPP is a program for statistical analysis of sampled data. It
is a free replacement for the proprietary program SPSS.

PSPP development is ongoing. It already supports a large subset of
SPSS's syntax. Its statistical procedure support is currently
limited, but growing. At your option, PSPP will produce statistical
reports in ASCII, PostScript, PDF, HTML, SVG, or OpenDocument formats.


%package devel
Summary:        Development files for pspp, a statistical analysis program
Group:          Development/Libraries/C and C++
License:        LGPL-2.1+
Requires:       glibc-devel
Requires:       gsl-devel
Requires:       libxml2-devel
Requires:       postgresql-devel
Requires:       zlib-devel

%description devel
PSPP is a program for statistical analysis of sampled data. It
is a free replacement for the proprietary program SPSS.

This subpackage contains libraries and header files for developing
applications that want to build pspp plugins.

%prep
%if 0%{?fedora} || 0%{?rhel_version} || 0%{?centos_version} || 0%{?mandriva_version}
%setup -q -n pspp-%{version}
%else
%setup -n pspp-%{version}
%endif

%patch0 -p1
%patch1 -p1
%if 0%{?suse_version} <= 1320
%patch2 -p1
%endif

%build
export SUSE_ASNEEDED=0
export CFLAGS="%{optflags} -fgnu89-inline"
%if 0%{?suse_version} <= 1320
autoreconf -f -i
%endif
%configure \
             --disable-relocatable --disable-static --disable-rpath \
             --enable-debug --without-libreadline-prefix

#Fix "File is compiled without RPM_OPT_FLAGS"
make

%install
%make_install
%if 0%{?suse_version}
%suse_update_desktop_file -r %{name} Education Math
%endif

%if 0%{?mandriva_version}
# do nothing
%else
# don't own /usr/share/info/dir
rm %{buildroot}/%{_infodir}/dir
%endif

#Config for ld
mkdir -p %{buildroot}/etc/ld.so.conf.d
cat >%{buildroot}/etc/ld.so.conf.d/pspp.conf <<EOF
%if 0%{?suse_version} > 1120
%{_libdir}/pspp
%endif
EOF

%if 0%{?suse_version}
%fdupes -s %{buildroot}/%_datadir
%endif

# localization
%find_lang pspp

%check
#make check || cat ./tests/testsuite.log

%post
/sbin/ldconfig
%install_info  --info-dir=%{_infodir}/dir  %{_infodir}/pspp.info
%if 0%{?suse_version} >= 1140
%desktop_database_post
%endif

%preun
if [ $1 = 0 ] ; then
   %install_info_delete --info-dir=%{_infodir}/dir %{_infodir}/pspp.info*
fi

%postun
/sbin/ldconfig
%if 0%{?suse_version} >= 1140
%desktop_database_postun
%endif

%files -f pspp.lang
%defattr(-,root,root,-)
%doc README COPYING THANKS AUTHORS
# tests/testsuite.log
%config(noreplace) /etc/ld.so.conf.d/pspp.conf
%{_bindir}/pspp
%{_bindir}/psppire
%{_bindir}/pspp-dump-sav
%{_bindir}/pspp-convert
%defattr(644,root,root,755)
%{_infodir}/pspp*
%dir %{_libdir}/pspp/
%{_libdir}/pspp/*.so
%{_datadir}/pspp
%doc %{_datadir}/doc/pspp
%{_datadir}/icons/hicolor/scalable/apps/pspp.svg
%{_datadir}/icons/hicolor/16x16/apps/pspp.png
%{_datadir}/icons/hicolor/16x16/mimetypes/application-x-spss-por.png
%{_datadir}/icons/hicolor/16x16/mimetypes/application-x-spss-sav.png
%{_datadir}/icons/hicolor/16x16/mimetypes/application-x-spss-sps.png
%{_datadir}/icons/hicolor/16x16/mimetypes/application-x-spss-zsav.png
%{_datadir}/icons/hicolor/22x22/apps/pspp.png
%{_datadir}/icons/hicolor/22x22/mimetypes/application-x-spss-por.png
%{_datadir}/icons/hicolor/22x22/mimetypes/application-x-spss-sav.png
%{_datadir}/icons/hicolor/22x22/mimetypes/application-x-spss-sps.png
%{_datadir}/icons/hicolor/22x22/mimetypes/application-x-spss-zsav.png
%{_datadir}/icons/hicolor/24x24/apps/pspp.png
%{_datadir}/icons/hicolor/24x24/mimetypes/application-x-spss-por.png
%{_datadir}/icons/hicolor/24x24/mimetypes/application-x-spss-sav.png
%{_datadir}/icons/hicolor/24x24/mimetypes/application-x-spss-sps.png
%{_datadir}/icons/hicolor/24x24/mimetypes/application-x-spss-zsav.png
%{_datadir}/icons/hicolor/256x256/apps/pspp.png
%{_datadir}/icons/hicolor/256x256/mimetypes/application-x-spss-por.png
%{_datadir}/icons/hicolor/256x256/mimetypes/application-x-spss-sav.png
%{_datadir}/icons/hicolor/256x256/mimetypes/application-x-spss-sps.png
%{_datadir}/icons/hicolor/256x256/mimetypes/application-x-spss-zsav.png
%{_datadir}/icons/hicolor/32x32/apps/pspp.png
%{_datadir}/icons/hicolor/32x32/mimetypes/application-x-spss-por.png
%{_datadir}/icons/hicolor/32x32/mimetypes/application-x-spss-sav.png
%{_datadir}/icons/hicolor/32x32/mimetypes/application-x-spss-sps.png
%{_datadir}/icons/hicolor/32x32/mimetypes/application-x-spss-zsav.png
%{_datadir}/icons/hicolor/48x48/apps/pspp.png
%{_datadir}/icons/hicolor/48x48/mimetypes/application-x-spss-por.png
%{_datadir}/icons/hicolor/48x48/mimetypes/application-x-spss-sav.png
%{_datadir}/icons/hicolor/48x48/mimetypes/application-x-spss-sps.png
%{_datadir}/icons/hicolor/48x48/mimetypes/application-x-spss-zsav.png
%{_datadir}/applications/pspp.desktop
%if 0%{?mandriva_version}
%doc %{_mandir}/man1/pspp.1.xz
%doc %{_mandir}/man1/psppire.1.xz
%doc %{_mandir}/man1/pspp-dump-sav.1.xz
%doc %{_mandir}/man1/pspp-convert.1.xz
%else
%doc %{_mandir}/man1/pspp.1.gz
%doc %{_mandir}/man1/psppire.1.gz
%doc %{_mandir}/man1/pspp-dump-sav.1.gz
%doc %{_mandir}/man1/pspp-convert.1.gz
%endif
%dir %{_datadir}/appdata/
%{_datadir}/appdata/pspp.appdata.xml

%files devel
%defattr(-, root, root)
%dir %{_libdir}/pspp/
%{_libdir}/pspp/libpspp-core.la
%{_libdir}/pspp/libpspp.la

%changelog
* Thu Feb 28 2019 opensuse.lietuviu.kalba@gmail.com
- Add upstream patch CVE-2019-9211.patch to fix CVE-2019-9211
  (boo#1127343).
* Wed Feb  6 2019 Jan Engelhardt <jengelh@inai.de>
- Remove excessive -n argument to %%build, and excessive %%defattr
  lines.
* Fri Jan  4 2019 Jan Engelhardt <jengelh@inai.de>
- Drop useless AutoReqProv: on.
* Thu Jan  3 2019 opensuse.lietuviu.kalba@gmail.com
- Add upstream patch CVE-2018-20230.patch to fix CVE-2018-20230
  (bnc#1120061).
- Add upstream patch avoid_old_Texinfo_4.13.patch to avoid
  compiling with old Texinfo 4.13.
* Sat Nov 10 2018 astieger@suse.com
- pspp 1.2.0:
  * New experimental command SAVE DATA COLLECTION to save MDD files
  * MTIME and YMDHMS variable formats now supported.
  * Spread sheet rendering now done via spread-sheet-widget
* Sat Nov 10 2018 astieger@suse.com
- add upstream signing key and verify source signature
* Mon Sep 11 2017 jengelh@inai.de
- Update boilerplate descriptions. Replace $RPM_ shell variables
  by macros. Unify mix of different CFLAGS.
* Tue Sep  5 2017 opensuse.lietuviu.kalba@gmail.com
- Removing ncurses dependency, because since 0.11.0 version,
  the ncurses library is no longer required or used.
* Tue Aug 29 2017 opensuse.lietuviu.kalba@gmail.com
- Update to 1.0.1 version:
  * Bug fixes, including fixes for CVE-2017-12958 (bnc#1054585),
    CVE-2017-12959 (bnc#1054588), CVE-2017-12960 (bnc#1054587), and
    CVE-2017-12961 (bnc#1054586).
  * Translation updates.
* Sun Aug 13 2017 opensuse.lietuviu.kalba@gmail.com
- Update to 0.11.0 version:
  * The REGRESSION command now has a /ORIGIN subcommand to perform
  regression through the origin.
  * The FACTOR command can now analyse matrix files prepared with MATRIX DATA.
  * The FACTOR command can now print the anti-image matrices.
  * The MATRIX DATA command has been added.
  * Some inappropriate properties in selection dialogs have been corrected.
  * A bug which could cause the HTML driver to go into a tight loop
  has been fixed.
  * An error in the FREQUENCIES procedure, where the word "Mean" was
  printed when "Variance" was appropriate has been fixed.
  * The ncurses library is no longer required or used.
  * A bug where the Mann-Whitney test would give misleading results
  if run on multiple variables and MISSING=ANALAYSIS was specified
  has been fixed.
  * Gtk+3.14.5 or later must now be used when building.
  * Graphical user interface changes:
  * There is a new menu: Edit|Options
  * The Non Parametric Statistics Menu has a new item: "K Independent Samples".
  * Dialog boxes can now be canceled using the <Escape> key.
  * The AUTORECODE command now accepts an optional / before INTO.
  * The short form of the VECTOR command can now create string variables.
  * Bug fixes, including fixes for CVE-2017-10791 and CVE-2017-10792.
- Drop pspp-0001-sys-file-reader-Avoid-null-dereference-skipping-bad-.patch:
  Fix for CVE-2017-10792 included in PSPP 0.11.0 version upstream.
- Drop pspp-0002-sys-file-reader-Fix-integer-overflows-in-parse_long_.patch:
  Fix for CVE-2017-10791 included in PSPP 0.11.0 version upstream.
* Sat Jul 29 2017 opensuse.lietuviu.kalba@gmail.com
- Add pspp-0001-sys-file-reader-Avoid-null-dereference-skipping-bad-.patch
  to fix NULL Pointer dereference in ll_insert (bnc#1046997, CVE-2017-10792).
- Add pspp-0002-sys-file-reader-Fix-integer-overflows-in-parse_long_.patch
  to fix  Integer overflow in the hash_int library (bnc#1046998, CVE-2017-10791).
* Mon Feb  6 2017 dimstar@opensuse.org
- Port to ncurses6 (instead of using the deprecated mcurses5):
  + export NCURSES_CONFIG=%%{_bindir}/ncurses6-config if the binary
    exists. In case it does not, the default search algorithm of
    configure is being used, meaning ncurses5-config, followed by
    ncurses8-config.
* Wed Aug  3 2016 opensuse.lietuviu.kalba@gmail.com
- Update to 0.10.2:
  * CROSSTABS implements a new COUNT subcommand to round case or cell
  weights.
  * Help will be opened as HTML in default browser if yelp
  is not available.
  * When plotting scatterplots with only one dataset (the simple case)
  the colour used for the dataset is now black. The previous default
  from the Tango palette was too faint to see easily.
  * The varible info dialog could previously only paste a single variable.
  Now it can paste multiple variables.
  * Bug fixes, including the following:
  - T-test with independent samples GUI crashed with string
    type variable as group variable.
  - The variable info dialog showed the previous selected variable
    superimposed with the currently selected one.
  - The GLM command did not properly deal with missing values. This
    has been fixed.
* Sun Apr  3 2016 opensuse.lietuviu.kalba@gmail.com
- Update to 0.10:
  * The QUICK CLUSTER command has a  /PRINT subcommand which shows
  the initial cluster centres and the final cluster membership of
  each case.  The clustering algorithm has also been updated, so
  as to produce better separated clusters.
  * If the DECIMAL character is set to COMMA then the ',' character
  will not be treated as a separator by DATA LIST.
  * The graphical user interface (psppire) has been changed as follows:
  - It now uses Gtk+ version 3 instead of version 2.
  - There is now a Graphs menu to access the GRAPH command.
  - The status of dialog box widgets are now preserved between calls
    to the same dialog box for the same dataset.
  - The dialog box for the Logistic Regression command will now
    infer that string variables or any varible with a "measure"
    of Nominal or Ordinal are to be treated as categorical variables
    and will generate syntax accordingly.
  * The pspp-convert utility can now decrypt encrypted syntax files.
  The encrypted syntax file format is unacceptably insecure, so to
  discourage its use PSPP and PSPPIRE do not directly read or write
  this format.
  * New commands:
  - SORT VARIABLES.
  * The following functions for transformation expressions are new:
  - REPLACE, for search-and-replace of one string with another.
  - STRUNC, to truncate a string and trim trailing spaces.
  - MEDIAN, to compute the median of its arguments.
  - The TRUNC function in expressions now supports additional arguments
    for truncating to values other than integers and to indicate a level
    of rounding fuzz.  The default rounding fuzz may now be controlled
    and displayed with SET FUZZBITS and SHOW FUZZBITS, respectively.
  * Various bug fixes.
* Tue Aug 18 2015 opensuse.lietuviu.kalba@gmail.com
- Update to 0.8.5:
  * The FREQUENCIES and CROSSTABS commands can now generate barcharts.
  * The FACTOR command can now perform PROMAX rotations.
  * SPSS/PC+ system files are now supported on GET and other commands
    that read SPSS system files.  The pspp-convert program can now read
    SPSS/PC+ system files.  Writing the obsolete SPSS/PC+ system file
    format is not supported.
  * SYSFILE INFO can now read SPSS/PC+ system files and SPSS portable
    files.
  * FREQUENCIES: A bug was fixed where an assertion failure occured
    when an empty dataset was presented.
  * The GRAPH command is now available.  Initially it supports
    scatterplots and histograms.
  * The RND operator in expressions now supports additional operands
    for rounding to values other than integers and to indicate a level
    of rounding fuzz.  The default rounding fuzz may now be controlled
    and displayed with SET FUZZBITS and SHOW FUZZBITS, respectively.
* Mon Nov  3 2014 embar@super.lt
- Update to 0.8.4:
  * Bug fixes.
  * More detailed changelog can be found here:
    http://git.savannah.gnu.org/cgit/pspp.git/tree/NEWS
* Sat Apr 26 2014 embar@super.lt
- Update to 0.8.3:
  * Independent T-Tests displayed the standard error of the difference
  and the confidence interval for the unequal variances case, where
  the equal variances case should have been.  This has been fixed.
  * REGRESSION now recognises /STATISTICS=CI(x) which causes confidence
  intervals for the coefficients to be printed.
  * When DESCRIPTIVES calculates Z scores, it now omits cases filtered
  by the current FILTER settings.
  * PSPPIRE graphical user interface improvements.
  * System file related improvements.
* Thu Apr 10 2014 embar@super.lt
- Update to 0.8.2.1. Detailed changelog can be found here:
  http://git.savannah.gnu.org/cgit/pspp.git/tree/NEWS
* Sun Jan 26 2014 embar@super.lt
- Update to 0.8.2. Detailed changelog can be found here:
  http://git.savannah.gnu.org/cgit/pspp.git/tree/NEWS
* Thu Aug  1 2013 embar@super.lt
- Update to 0.8.0. Detailed changelog can be found here:
  http://git.savannah.gnu.org/cgit/pspp.git/tree/NEWS
* Tue May  7 2013 embar@super.lt
- merged 'psppsheet' branch
* Wed Mar 27 2013 embar@super.lt
- Update to 0.7.10
* Tue Jan 10 2012 embar@super.lt
- Update to 0.7.8-gbc9098
- Fix compiling for openSUSE 12.1
* Fri Aug 20 2010 embar@super.lt
- Update to 0.7.5-g7803d3
* Fri Nov 14 2008 Detlef Steuer <steuer@hsuhh.de> - 0.6.1-0
- First try for the Opensuse Buildservice
* Thu Sep 25 2008 Matj Cepl <mcepl@redhat.com> - 0.6.0-8
- Fix wrong CFLAGS -- add -fgnu89-inline
* Mon Jul  7 2008 Matej Cepl <mcepl@redhat.com> 0.6.0-7
- Fix BuildRequires.
* Wed Jun 18 2008 Matej Cepl <mcepl@redhat.com> 0.6.0-6
- Bug 451006 has been resolved, so we don't have to munge CFLAGS
  anymore.
* Sat Jun 14 2008 Matj Cepl <mcepl@redhat.com> 0.6.0-5
- Approved version with fixed duplicate %%%%{_sysconfdir}/pspp
* Fri Jun 13 2008 Matj Cepl <mcepl@redhat.com> 0.6.0-4
- Second wave of Package Review -- .desktop file
- Mysterious libraries eliminated
* Thu Jun 12 2008 Matj Cepl <mcepl@redhat.com> 0.6.0-3
- First wave of Package Review nitpicking -- added %%%%doc and fixed Texinfo
  handling.
* Thu Jun 12 2008 Matj Cepl <mcepl@redhat.com> 0.6.0-2
- Upstream release, this build is to be put into the package review.
* Tue Apr 22 2008 Matj Cepl <mcepl@redhat.com> 0.6.0-0.1.pre2
- Upstream pre-release.
* Mon Apr 23 2007 Matej Cepl <mcepl@redhat.com> - 0.4.0-1
- The first experimental package of PSPP for Fedora.
